package com.ruoyi.postCheck.mapper;

import java.util.List;

import com.ruoyi.postCheck.domain.PostCheckedItems;
import com.ruoyi.postCheck.domain.PostList;
import com.ruoyi.postCheck.domain.PostListInfo;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.postCheck.domain.homePage.PostCheckedUnCheckedView;
import org.apache.ibatis.annotations.Param;

/**
 * 岗检责任制清单Mapper接口
 *
 * @author csg
 * @date 2023-12-20
 */
public interface PostListMapper extends BaseMapper<PostList> {
    /**
     * 查询岗检责任制清单
     *
     * @param id 岗检责任制清单主键
     * @return 岗检责任制清单
     */
    public PostList selectPostListById(Long id);

    /**
     * 查询岗检责任制清单列表
     *
     * @param postList 岗检责任制清单
     * @return 岗检责任制清单集合
     */
    public List<PostList> selectPostListList(PostList postList);

    /**
     * 新增岗检责任制清单
     *
     * @param postList 岗检责任制清单
     * @return 结果
     */
    public int insertPostList(PostList postList);

    /**
     * 修改岗检责任制清单
     *
     * @param postList 岗检责任制清单
     * @return 结果
     */
    public int updatePostList(PostList postList);

    /**
     * 删除岗检责任制清单
     *
     * @param id 岗检责任制清单主键
     * @return 结果
     */
    public int deletePostListById(Long id);

    /**
     * 批量删除岗检责任制清单
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePostListByIds(Long[] ids);

    /**
     * 批量删除岗检责任制清单明细
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePostListInfoByPostListIds(Long[] ids);

    /**
     * 批量新增岗检责任制清单明细
     *
     * @param postListInfoList 岗检责任制清单明细列表
     * @return 结果
     */
    public int batchPostListInfo(List<PostListInfo> postListInfoList);


    /**
     * 通过岗检责任制清单主键删除岗检责任制清单明细信息
     *
     * @param id 岗检责任制清单ID
     * @return 结果
     */
    public int deletePostListInfoByPostListId(Long id);

    List<PostCheckedItems> contentListByType(@Param("deptId")Long deptId, @Param("postId")Long postId, @Param("type")Integer type);

    Integer userTotal();

    List<PostCheckedUnCheckedView> postChecked(Integer status);

    Integer getPostCountByDeptId(Long deptId);
}
